@@ -1,21 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-/*
- * This file is part of Devhelp.
- *
- * Copyright (C) 2018 Sébastien Wilmet <swilmet@gnome.org>
- *
- * Devhelp is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation, either version 3 of the License,
- * or (at your option) any later version.
- *
- * Devhelp is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2018-2019 Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "dh-tab-label.h"
@@ -83,9 +68,7 @@ set_tab (DhTabLabel *tab_label,
         g_return_if_fail (DH_IS_TAB (tab));
 
         g_assert (tab_label->priv->tab == NULL);
-        tab_label->priv->tab = tab;
-        g_object_add_weak_pointer (G_OBJECT (tab_label->priv->tab),
-                                   (gpointer *) &tab_label->priv->tab);
+        g_set_weak_pointer (&tab_label->priv->tab, tab);
 
         web_view = dh_tab_get_web_view (tab);
         g_signal_connect_object (web_view,
@@ -140,11 +123,7 @@ dh_tab_label_dispose (GObject *object)
 {
         DhTabLabel *tab_label = DH_TAB_LABEL (object);
 
-        if (tab_label->priv->tab != NULL) {
-                g_object_remove_weak_pointer (G_OBJECT (tab_label->priv->tab),
-                                              (gpointer *) &tab_label->priv->tab);
-                tab_label->priv->tab = NULL;
-        }
+        g_clear_weak_pointer (&tab_label->priv->tab);
 
         G_OBJECT_CLASS (dh_tab_label_parent_class)->dispose (object);
 }
