@@ -1,6 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-/*
- * SPDX-FileCopyrightText: 2001-2003 CodeFactory AB
+/* SPDX-FileCopyrightText: 2001-2003 CodeFactory AB
  * SPDX-FileCopyrightText: 2001-2008 Imendio AB
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -9,7 +8,6 @@
 #include <locale.h>
 #include <glib/gi18n.h>
 #include <devhelp/devhelp.h>
-#include <amtk/amtk.h>
 #include "dh-app.h"
 #include "dh-settings-app.h"
 
@@ -23,13 +21,11 @@ main (int argc, char **argv)
         textdomain (GETTEXT_PACKAGE);
 
         dh_init ();
-        amtk_init ();
 
         application = dh_app_new ();
         status = g_application_run (G_APPLICATION (application), argc, argv);
         g_object_unref (application);
 
-        amtk_finalize ();
         dh_finalize ();
         dh_settings_app_unref_singleton ();
 
